@@ -294,6 +294,7 @@ sub sqlize {
 
   # "where_on" : conditions to be added in joins
   if (my $where_on = $args->{-where_on}) {
+
     # check proper usage
     does $sqla_args{-from}, 'ARRAY'
       or croak "datasource for '-where_on' was not a join";
@@ -301,24 +302,23 @@ sub sqlize {
     # retrieve components of the join and check again for proper usage
     my ($join_op, $first_table, @other_join_args) = @{$sqla_args{-from}};
     $join_op eq '-join'
-      or croak "datasource for '-where_on' was not a join";
+      or croak "the '-where_on' argument can only be used on a 'join' datasource";
 
-    # reverse index (table_name => $join_hash)
+    # build a hash where keys are the database table names, and values are the join conditions (hashes)
     my %by_dest_table = reverse @other_join_args;
 
-    # insert additional conditions into appropriate places
+    # additional conditions coming from the -where_on hash are inserted as additional join criteria
     while (my ($table, $additional_cond) = each %$where_on) {
-      my $join_cond = $by_dest_table{$table}
-        or croak "-where_on => {'$table' => ..}: this table is not in the join";
+      my $db_table  = $meta_source->{db_table_by_source}{$table};
+      no warnings 'uninitialized';
+      my $join_cond =  $by_dest_table{$db_table} # new preferred syntax : through association or alias names
+                    || $by_dest_table{$table}    # backwards compat : database names are accepted too
+        or croak "-where_on => {'$table' => ..}: there is no such table in the join ", $meta_source->class;
       $join_cond->{condition}
         = $sql_abstract->merge_conditions($join_cond->{condition},
                                           $additional_cond);
       delete $join_cond->{using};
     }
-
-    # TODO: should be able to use paths and aliases as keys, instead of
-    # database table names.
-    # TOCHECK: is this stuff still compatible with the bind() method ?
   }
 
   # adjust join conditions for ON clause or for USING clause
